summaryrefslogtreecommitdiff
path: root/chromium/services/device/device_service.h
diff options
context:
space:
mode:
authorAllan Sandfeld Jensen <allan.jensen@qt.io>2018-01-29 16:35:13 +0100
committerAllan Sandfeld Jensen <allan.jensen@qt.io>2018-02-01 15:33:35 +0000
commitc8c2d1901aec01e934adf561a9fdf0cc776cdef8 (patch)
tree9157c3d9815e5870799e070b113813bec53e0535 /chromium/services/device/device_service.h
parentabefd5095b41dac94ca451d784ab6e27372e981a (diff)
downloadqtwebengine-chromium-c8c2d1901aec01e934adf561a9fdf0cc776cdef8.tar.gz
BASELINE: Update Chromium to 64.0.3282.139
Change-Id: I1cae68fe9c94ff7608b26b8382fc19862cdb293a Reviewed-by: Alexandru Croitor <alexandru.croitor@qt.io>
Diffstat (limited to 'chromium/services/device/device_service.h')
-rw-r--r--chromium/services/device/device_service.h23
1 files changed, 18 insertions, 5 deletions
diff --git a/chromium/services/device/device_service.h b/chromium/services/device/device_service.h
index 7ac36d2724a..383f76f7584 100644
--- a/chromium/services/device/device_service.h
+++ b/chromium/services/device/device_service.h
@@ -7,6 +7,8 @@
#include "base/memory/ref_counted.h"
#include "build/build_config.h"
+#include "device/geolocation/geolocation_provider_impl.h"
+#include "device/geolocation/public/interfaces/geolocation_context.mojom.h"
#include "device/screen_orientation/public/interfaces/screen_orientation.mojom.h"
#include "device/sensors/public/interfaces/orientation.mojom.h"
#include "mojo/public/cpp/bindings/binding_set.h"
@@ -27,7 +29,11 @@
#if defined(OS_ANDROID)
#include "base/android/scoped_java_ref.h"
#else
-#include "device/hid/public/interfaces/hid.mojom.h"
+#include "services/device/public/interfaces/hid.mojom.h"
+#endif
+
+#if defined(OS_LINUX) && defined(USE_UDEV)
+#include "services/device/public/interfaces/input_service.mojom.h"
#endif
namespace base {
@@ -44,18 +50,20 @@ class PowerMonitorMessageBroadcaster;
class TimeZoneMonitor;
#if defined(OS_ANDROID)
// NOTE: See the comments on the definitions of |WakeLockContextCallback|
// and NFCDelegate.java to understand the semantics and usage of these
// parameters.
std::unique_ptr<service_manager::Service> CreateDeviceService(
scoped_refptr<base::SingleThreadTaskRunner> file_task_runner,
scoped_refptr<base::SingleThreadTaskRunner> io_task_runner,
const WakeLockContextCallback& wake_lock_context_callback,
+ const CustomLocationProviderCallback& custom_location_provider_callback,
const base::android::JavaRef<jobject>& java_nfc_delegate);
#else
std::unique_ptr<service_manager::Service> CreateDeviceService(
scoped_refptr<base::SingleThreadTaskRunner> file_task_runner,
- scoped_refptr<base::SingleThreadTaskRunner> io_task_runner);
+ scoped_refptr<base::SingleThreadTaskRunner> io_task_runner,
+ const CustomLocationProviderCallback& custom_location_provider_callback);
#endif
class DeviceService : public service_manager::Service {
@@ -79,6 +87,11 @@ class DeviceService : public service_manager::Service {
mojo::ScopedMessagePipeHandle interface_pipe) override;
void BindFingerprintRequest(mojom::FingerprintRequest request);
+ void BindGeolocationContextRequest(mojom::GeolocationContextRequest request);
+
+#if defined(OS_LINUX) && defined(USE_UDEV)
+ void BindInputDeviceManagerRequest(mojom::InputDeviceManagerRequest request);
+#endif
void BindOrientationSensorRequest(mojom::OrientationSensorRequest request);
@@ -44,18 +50,20 @@ class PowerMonitorMessageBroadcaster;
class TimeZoneMonitor;
#if defined(OS_ANDROID)
-// NOTE: See the comments on the definitions of |WakeLockContextCallback|
-// and NFCDelegate.java to understand the semantics and usage of these
-// parameters.
+// NOTE: See the comments on the definitions of |WakeLockContextCallback|,
+// |CustomLocationProviderCallback| and NFCDelegate.java to understand the
+// semantics and usage of these parameters.
std::unique_ptr<service_manager::Service> CreateDeviceService(
scoped_refptr<base::SingleThreadTaskRunner> file_task_runner,